@@ -1,4 +1,76 @@
 #' read_odf: all languages
+test_that("read_odf_all", {
+  df <- opendataformat::read_odf(
+    file = "testdata/data.odf.zip",
+    languages = "all"
+  )
+  # - dataset attributes
+  expect_equal(names(attributes(df)), c(
+    "row.names",
+    "names",
+    ".internal.selfref",
+    "study",
+    "name",
+    "description_en",
+    "description_de",
+    "label_en",
+    "label_de",
+    "url",
+    "languages",
+    "lang",
+    "label",
+    "class"
+  ))
+  # - variable attributes
+  expect_equal(names(attributes(df$bap87)), c(
+    "name",
+    "label_en",
+    "label_de",
+    "description_en",
+    "description_de",
+    "type",
+    "url",
+    "labels_en",
+    "labels_de",
+    "languages",
+    "lang",
+    "label"
+  ))
+  # - dataset content
+  expect_equal(attributes(df)$names, c("bap87", "bap9201", "bap9001", "bap9002",
+                                       "bap9003", "bap96", "name"))
+  expect_equal(attributes(df)$name, "bap")
+  expect_equal(attributes(df)$label, "Data from individual questionnaires 2010")
+  expect_equal(attributes(df)$label_de, "Daten vom Personenfragebogen 2010")
+  expect_equal(attributes(df)$label_en,
+               "Data from individual questionnaires 2010")
+  expect_equal(attributes(df)$description, NULL)
+  expect_equal(attributes(df)$description_en,
+               "The data were collected as part of the SOEP-Core study using the questionnaire \"Living in Germany - Survey 2010 on the social situation - Personal questionnaire for all. This questionnaire is addressed to the individual persons in the household. A view of the survey instrument can be found here: https://www.diw.de/documents/dokumentenarchiv/17/diw_01.c.369781.de/soepfrabo_personen_2010.pdf")
+  expect_equal(attributes(df)$description_de,
+               "Die Daten wurden im Rahmen der Studie SOEP-Core mittels des Fragebogens „Leben in Deutschland – Befragung 2010 zur sozialen Lage - Personenfragebogen für alle“ erhoben. Dieser Fragebogen richtet sich an die einzelnen Personen im Haushalt. Eine Ansicht des Erhebungsinstrumentes finden Sie hier: https://www.diw.de/documents/dokumentenarchiv/17/diw_01.c.369781.de/soepfrabo_personen_2010.pdf")
+  expect_equal(attributes(df)$url, "https://paneldata.org/soep-core/data/bap")
+  expect_equal(attributes(df)$class,  c("odf_tbl", "tbl_df", "tbl", "data.frame"))
+  # - variables content
+  expect_equal(attributes(df$bap96)$name, "bap96")
+  expect_equal(attributes(df$bap96)$label, "Height")
+  expect_equal(attributes(df$bap96)$label_de, "Körpergröße")
+  expect_equal(attributes(df$bap96)$label_en, "Height")
+  expect_equal(attributes(df$bap96)$description, NULL)
+  expect_equal(attributes(df$bap96)$description_de, "Körpergröße")
+  expect_equal(attributes(df$bap96)$description_en, "Body size")
+  expect_equal(attributes(df$bap96)$url,
+               "https://paneldata.org/soep-core/data/bap/bap96")
+  expect_equal(unname(attributes(df$bap96)$labels), NULL)
+  expect_equal(names(attributes(df$bap96)$labels), NULL)
+  expect_equal(unname(attributes(df$bap96)$labels_en), c(-2, -1))
+  expect_equal(names(attributes(df$bap96)$labels_en),
+               c("Does not apply", "No Answer"))
+  expect_equal(unname(attributes(df$bap96)$labels_de), c(-2, -1))
+  expect_equal(names(attributes(df$bap96)$labels_de),
+               c("trifft nicht zu", "keine Angabe"))
+})
+
 test_that("read_odf_all", {
   df <- opendataformat::read_odf(
     file = "testdata/data.zip",
@@ -70,10 +142,12 @@ test_that("read_odf_all", {
   expect_equal(names(attributes(df$bap96)$labels_de),
                c("trifft nicht zu", "keine Angabe"))
 })
+
+
 #' read_odf: with default language
 test_that("read_odf_variables", {
   df <- read_odf(
-    file = "testdata/data_with_default.zip",
+    file = "testdata/data_with_default.odf.zip",
     languages = "all"
   )
   # - dataset attributes
@@ -129,7 +203,7 @@ test_that("read_odf_variables", {
 #' read_odf: "de" languages
 test_that("read_odf_de", {
   df <- read_odf(
-    file = "testdata/data.zip",
+    file = "testdata/data.odf.zip",
     languages = "de"
   )
   # - dataset attributes
@@ -186,7 +260,7 @@ test_that("read_odf_de", {
 #' read_odf: nrows=10
 test_that("read_odf_specific_rows", {
   df <- read_odf(
-    file = "testdata/data.zip",
+    file = "testdata/data.odf.zip",
     nrows = 10
   )
   # - dataset attributes
@@ -264,7 +338,7 @@ test_that("read_odf_specific_rows", {
 #' read_odf: nrows = 13, skip = 3
 test_that("read_odf_specific_rows2", {
   df <- read_odf(
-    file = "testdata/data.zip",
+    file = "testdata/data.odf.zip",
     nrows = 13,
     skip = 3
   )
@@ -344,7 +418,7 @@ test_that("read_odf_specific_rows2", {
 #' read_odf: select =c(1,2,4,5)
 test_that("read_odf_specific_variables", {
   df <- read_odf(
-    file = "testdata/data.zip",
+    file = "testdata/data.odf.zip",
     select = c(1, 2, 4, 5)
   )
   # - dataset attributes
@@ -406,7 +480,7 @@ test_that("read_odf_specific_variables", {
 #' read_odf: select = c("bap87", "bap96", "bap9002", "bap9003")
 test_that("read_odf_specific_variables", {
   df <- read_odf(
-    file = "testdata/data.zip",
+    file = "testdata/data.odf.zip",
     select = c("bap87", "bap96", "bap9002",
                "bap9003")
   )
@@ -487,7 +561,7 @@ test_that("read_odf_specific_variables", {
 #' read_odf: rows and cols
 test_that("read_odf_specific_rows_and_cols", {
   df <- read_odf(
-    file = "testdata/data.zip",
+    file = "testdata/data.odf.zip",
     nrows = 13,
     skip = 3,
     select = c(1, 2, 4, 5)
@@ -573,7 +647,7 @@ test_that("read_odf_specific_rows_and_cols", {
 #' read_odf: rows and cols2
 test_that("read_odf_specific_rows_and_cols2", {
   df <- read_odf(
-    file = "testdata/data.zip",
+    file = "testdata/data.odf.zip",
     nrows = 13,
     skip = 3,
     select = c("bap87", "bap9201", "bap9002",
@@ -660,7 +734,7 @@ test_that("read_odf_specific_rows_and_cols2", {
 #' read_odf: language rows and cols
 test_that("read_odf_specific_language_rows_and_cols", {
   df <- read_odf(
-    file = "testdata/data.zip",
+    file = "testdata/data.odf.zip",
     nrows = 13,
     skip = 3,
     select = c("bap87", "bap9201", "bap9002",
